==> jbpm-distro-4.0.jar: jbpm-4.0/src/org/jbpm/pvm/internal/history/model/HistoryPriorityUpdateImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.internal.history.model;


/**
 * @author Tom Baeyens
 */
public class HistoryPriorityUpdateImpl extends HistoryDetailImpl {

  private static final long serialVersionUID = 1L;
  
  public int oldPriority;
  public int newPriority;

  public HistoryPriorityUpdateImpl() {
  }

  public HistoryPriorityUpdateImpl(int oldPriority, int newPriority) {
    // superclass has dummy string constructor to differentiate from  
    // the default constructor which is used by hibernate 
    super(null);
    this.oldPriority = oldPriority;
    this.newPriority = newPriority;
  }
}

==> jbpm-distro-4.1.jar: jbpm-4.1/src/org/jbpm/pvm/internal/history/model/HistoryPriorityUpdateImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.pvm.internal.history.model;


/**
 * @author Tom Baeyens
 */
public class HistoryPriorityUpdateImpl extends HistoryDetailImpl {

  private static final long serialVersionUID = 1L;
  
  public int oldPriority;
  public int newPriority;

  public HistoryPriorityUpdateImpl() {
  }

  public HistoryPriorityUpdateImpl(int oldPriority, int newPriority) {
    // superclass has dummy string constructor to differentiate from  
    // the default constructor which is used by hibernate 
    super(null);
    this.oldPriority = oldPriority;
    this.newPriority = newPriority;
  }
  
  public String toString() {
    return (userId!=null ? userId+" updated priority" : "priority updated")+" from "+oldPriority+" to "+newPriority; 
  }
}
